@@ -3,8 +3,10 @@ import inspect
 import logging
 import pickle
 import sys
-from typing import Any, Callable, Dict, List, Optional, Sequence, Type, Union
+from functools import lru_cache
+from typing import Any, Callable, Dict, List, Sequence, Tuple, Type
 
+from django.apps import AppConfig
 from django.conf import settings
 from django.core.cache import caches
 from django.core.exceptions import ImproperlyConfigured
@@ -15,7 +17,6 @@ from django.utils.decorators import classonlymethod
 from django.views.generic.base import TemplateView
 
 import shortuuid
-from cachetools.lru import LRUCache
 
 from django_unicorn.settings import get_cache_alias
 
@@ -32,6 +33,12 @@ from .fields import UnicornField
 from .unicorn_template_response import UnicornTemplateResponse
 
 
+try:
+    from cachetools.lru import LRUCache
+except ImportError:
+    from cachetools import LRUCache
+
+
 logger = logging.getLogger(__name__)
 
 
@@ -63,7 +70,8 @@ def convert_to_pascal_case(s: str) -> str:
     return "".join(word.title() for word in s.split("_"))
 
 
-def get_locations(component_name):
+@lru_cache(maxsize=128, typed=True)
+def get_locations(component_name: str) -> List[Tuple[str, str]]:
     locations = []
 
     if "." in component_name:
@@ -101,8 +109,21 @@ def get_locations(component_name):
     for app in unicorn_apps:
         # Handle an installed app that actually points to an app config
         if ".apps." in app:
+            is_app_config = True  # default to True for backwards compatibility
             app_config_idx = app.rindex(".apps.")
-            app = app[:app_config_idx]
+
+            try:
+                app_config_module_name = app[: app_config_idx + 5]
+                app_config_class_name = app[app_config_idx + 6 :]
+                app_config_module = importlib.import_module(app_config_module_name)
+                is_app_config = type(
+                    getattr(app_config_module, app_config_class_name)
+                ) == type(AppConfig)
+            except ModuleNotFoundError:
+                pass
+
+            if is_app_config:
+                app = app[:app_config_idx]
 
         app_module_name = f"{app}.components.{module_name}"
         locations.append((app_module_name, class_name))
@@ -144,9 +165,6 @@ def construct_component(
     return component
 
 
-from django.utils.decorators import classonlymethod
-
-
 class UnicornView(TemplateView):
     response_class = UnicornTemplateResponse
     component_name: str = ""
@@ -395,6 +413,9 @@ class UnicornView(TemplateView):
         # Re-set `request` on the component that got removed when making it cacheable
         self.request = request
 
+        for child in self.children:
+            child.request = request
+
     @timed
     def get_frontend_context_variables(self) -> str:
         """
@@ -482,7 +503,16 @@ class UnicornView(TemplateView):
         attributes = self._attributes()
         context.update(attributes)
         context.update(self._methods())
-        context.update({"unicorn": {"errors": self.errors}})
+        context.update(
+            {
+                "unicorn": {
+                    "component_id": self.component_id,
+                    "component_name": self.component_name,
+                    "component_key": self.component_key,
+                    "errors": self.errors,
+                }
+            }
+        )
 
         return context
 
@@ -843,9 +873,11 @@ class UnicornView(TemplateView):
                 component._cache_component(request, parent, **kwargs)
 
                 return component
-            except ModuleNotFoundError:
+            except ModuleNotFoundError as e:
+                logger.debug(e)
                 pass
-            except AttributeError:
+            except AttributeError as e:
+                logger.debug(e)
                 class_name_not_found = f"{module_name}.{class_name}"
 
         if class_name_not_found is not None:
